==> annot8-conventions-0.1.0-sources.jar: io/annot8/conventions/PropertyKeys.java <==
/* Annot8 (annot8.io) - Licensed under Apache-2.0. */
package io.annot8.conventions;

public class PropertyKeys {

  public static final String PROPERTY_KEY_ACCESSEDAT = "accessedat";
  public static final String PROPERTY_KEY_ACCOUNTNUMBER = "accountnumber";
  public static final String PROPERTY_KEY_ACCOUNTTYPE = "accounttype";
  public static final String PROPERTY_KEY_BRANCHCODE = "branchcode";
  public static final String PROPERTY_KEY_BANKCODE = "bankcode";
  public static final String PROPERTY_KEY_COUNTRY = "country";
  public static final String PROPERTY_KEY_END = "end";
  public static final String PROPERTY_KEY_FIRSTNAME = "firstname";
  public static final String PROPERTY_KEY_GENDER = "gender";
  public static final String PROPERTY_KEY_IDENTIFIER = "identifier";
  public static final String PROPERTY_KEY_NAME = "name";
  public static final String PROPERTY_KEY_NATIONALITY = "nationality";
  public static final String PROPERTY_KEY_REGISTRATION = "registration";
  public static final String PROPERTY_KEY_REFERENCE = "reference";
  public static final String PROPERTY_KEY_SOURCE = "source";
  public static final String PROPERTY_KEY_START = "start";
  public static final String PROPERTY_KEY_SURNAME = "surname";
  public static final String PROPERTY_KEY_TITLE = "title";
  public static final String PROPERTY_KEY_UNIT = "unit";
  public static final String PROPERTY_KEY_VALUE = "value";
  public static final String PROPERTY_KEY_VERSION = "version";

  private PropertyKeys() {
    // No constructor - only access to public methods
  }
}

==> annot8-conventions-0.2.0-sources.jar: io/annot8/conventions/PropertyKeys.java <==
/* Annot8 (annot8.io) - Licensed under Apache-2.0. */
package io.annot8.conventions;

public class PropertyKeys {

  public static final String PROPERTY_KEY_ACCESSEDAT = "accessedAt";
  public static final String PROPERTY_KEY_ACCOUNTNUMBER = "accountNumber";
  public static final String PROPERTY_KEY_ACCOUNTTYPE = "accountType";
  public static final String PROPERTY_KEY_BRANCHCODE = "branchCode";
  public static final String PROPERTY_KEY_BANKCODE = "bankCode";
  public static final String PROPERTY_KEY_COORDINATETYPE = "coordinateType";
  public static final String PROPERTY_KEY_COUNTRY = "country";
  public static final String PROPERTY_KEY_END = "end";
  public static final String PROPERTY_KEY_FIRSTNAME = "firstname";
  public static final String PROPERTY_KEY_GENDER = "gender";
  public static final String PROPERTY_KEY_IDENTIFIER = "identifier";
  public static final String PROPERTY_KEY_LANGUAGE = "language";
  public static final String PROPERTY_KEY_NAME = "name";
  public static final String PROPERTY_KEY_NATIONALITY = "nationality";
  public static final String PROPERTY_KEY_REGISTRATION = "registration";
  public static final String PROPERTY_KEY_REFERENCE = "reference";
  public static final String PROPERTY_KEY_SOURCE = "source";
  public static final String PROPERTY_KEY_START = "start";
  public static final String PROPERTY_KEY_SURNAME = "surname";
  public static final String PROPERTY_KEY_TITLE = "title";
  public static final String PROPERTY_KEY_UNIT = "unit";
  public static final String PROPERTY_KEY_VALUE = "value";
  public static final String PROPERTY_KEY_VERSION = "version";

  private PropertyKeys() {
    // No constructor - only access to public methods
  }
}
